@@ -48,9 +48,11 @@ class EmrConnection(AWSQueryConnection):
                                             'elasticmapreduce.us-east-1.amazonaws.com')
     ResponseError = EmrResponseError
 
-    # Constants for AWS Console debugging
-    DebuggingJar = 's3n://us-east-1.elasticmapreduce/libs/script-runner/script-runner.jar'
-    DebuggingArgs = 's3n://us-east-1.elasticmapreduce/libs/state-pusher/0.1/fetch'
+
+
+    # Constants for AWS Console debugging    
+    DebuggingJar = 's3://{region_name}.elasticmapreduce/libs/script-runner/script-runner.jar'
+    DebuggingArgs = 's3://{region_name}.elasticmapreduce/libs/state-pusher/0.1/fetch'
 
     def __init__(self, aws_access_key_id=None, aws_secret_access_key=None,
                  is_secure=True, port=None, proxy=None, proxy_port=None,
@@ -96,6 +98,10 @@ class EmrConnection(AWSQueryConnection):
 
     def describe_jobflow(self, jobflow_id):
         """
+        This method is deprecated. We recommend you use list_clusters,
+        describe_cluster, list_steps, list_instance_groups and
+        list_bootstrap_actions instead.
+
         Describes a single Elastic MapReduce job flow
 
         :type jobflow_id: str
@@ -108,6 +114,10 @@ class EmrConnection(AWSQueryConnection):
     def describe_jobflows(self, states=None, jobflow_ids=None,
                            created_after=None, created_before=None):
         """
+        This method is deprecated. We recommend you use list_clusters,
+        describe_cluster, list_steps, list_instance_groups and
+        list_bootstrap_actions instead.
+
         Retrieve all the Elastic MapReduce job flows on your account
 
         :type states: list
@@ -242,7 +252,7 @@ class EmrConnection(AWSQueryConnection):
 
         if instance_group_types:
             self.build_list_params(params, instance_group_types,
-                                   'InstanceGroupTypeList.member')
+                                   'InstanceGroupTypes.member')
 
         return self.get_object('ListInstances', params, InstanceList)
 
@@ -265,7 +275,7 @@ class EmrConnection(AWSQueryConnection):
             params['Marker'] = marker
 
         if step_states:
-            self.build_list_params(params, step_states, 'StepStateList.member')
+            self.build_list_params(params, step_states, 'StepStates.member')
 
         return self.get_object('ListSteps', params, StepSummaryList)
 
@@ -403,7 +413,7 @@ class EmrConnection(AWSQueryConnection):
                     action_on_failure='TERMINATE_JOB_FLOW', keep_alive=False,
                     enable_debugging=False,
                     hadoop_version=None,
-                    steps=[],
+                    steps=None,
                     bootstrap_actions=[],
                     instance_groups=None,
                     additional_info=None,
@@ -500,6 +510,7 @@ class EmrConnection(AWSQueryConnection):
         :rtype: str
         :return: The jobflow id
         """
+        steps = steps or []
         params = {}
         if action_on_failure:
             params['ActionOnFailure'] = action_on_failure
@@ -539,8 +550,8 @@ class EmrConnection(AWSQueryConnection):
             debugging_step = JarStep(name='Setup Hadoop Debugging',
                                      action_on_failure='TERMINATE_JOB_FLOW',
                                      main_class=None,
-                                     jar=self.DebuggingJar,
-                                     step_args=self.DebuggingArgs)
+                                     jar=self.DebuggingJar.format(region_name=self.region.name),    
+                                     step_args=self.DebuggingArgs.format(region_name=self.region.name))
             steps.insert(0, debugging_step)
 
         # Step args
