@@ -27,23 +27,21 @@ class Item(dict):
     SimpleDB item. An item in SDB is similar to a row in a relational
     database. Items belong to a :py:class:`Domain <boto.sdb.domain.Domain>`,
     which is similar to a table in a relational database.
-    
+
     The keys on instances of this object correspond to attributes that are
-    stored on the SDB item. 
-    
-    .. tip::
-        While it is possible to instantiate this class directly, you may want
-        to use the convenience methods on :py:class:`boto.sdb.domain.Domain`
-        for that purpose. For example, 
-        :py:meth:`boto.sdb.domain.Domain.get_item`.
+    stored on the SDB item.
+
+    .. tip:: While it is possible to instantiate this class directly, you may
+        want to use the convenience methods on :py:class:`boto.sdb.domain.Domain`
+        for that purpose. For example, :py:meth:`boto.sdb.domain.Domain.get_item`.
     """
     def __init__(self, domain, name='', active=False):
         """
         :type domain: :py:class:`boto.sdb.domain.Domain`
         :param domain: The domain that this item belongs to.
-        
+
         :param str name: The name of this item. This name will be used when
-            querying for items using methods like 
+            querying for items using methods like
             :py:meth:`boto.sdb.domain.Domain.get_item`
         """
         dict.__init__(self)
@@ -77,7 +75,7 @@ class Item(dict):
             else:
                 self.name = self.decode_value(value)
         elif name == 'Value':
-            if self.has_key(self.last_key):
+            if self.last_key in self:
                 if not isinstance(self[self.last_key], list):
                     self[self.last_key] = [self[self.last_key]]
                 value = self.decode_value(value)
@@ -104,8 +102,8 @@ class Item(dict):
     def load(self):
         """
         Loads or re-loads this item's attributes from SDB.
-        
-        .. warning:: 
+
+        .. warning::
             If you have changed attribute values on an Item instance,
             this method will over-write the values if they are different in
             SDB. For any local attributes that don't yet exist in SDB,
@@ -116,7 +114,7 @@ class Item(dict):
     def save(self, replace=True):
         """
         Saves this item to SDB.
-        
+
         :param bool replace: If ``True``, delete any attributes on the remote
             SDB item that have a ``None`` value on this object.
         """
@@ -125,7 +123,7 @@ class Item(dict):
         if replace:
             del_attrs = []
             for name in self:
-                if self[name] == None:
+                if self[name] is None:
                     del_attrs.append(name)
             if len(del_attrs) > 0:
                 self.domain.delete_attributes(self.name, del_attrs)
@@ -136,11 +134,11 @@ class Item(dict):
         attribute that has yet to be set, it will simply create an attribute
         named ``key`` with your given ``value`` as its value. If you are
         adding a value to an existing attribute, this method will convert the
-        attribute to a list (if it isn't already) and append your new value 
+        attribute to a list (if it isn't already) and append your new value
         to said list.
-        
+
         For clarification, consider the following interactive session:
-        
+
         .. code-block:: python
 
             >>> item = some_domain.get_item('some_item')
@@ -152,9 +150,9 @@ class Item(dict):
             >>> item.add_value('some_attr', 2)
             >>> item['some_attr']
             [1, 2]
-        
+
         :param str key: The attribute to add a value to.
-        :param object value: The value to set or append to the attribute. 
+        :param object value: The value to set or append to the attribute.
         """
         if key in self:
             # We already have this key on the item.
@@ -172,12 +170,8 @@ class Item(dict):
     def delete(self):
         """
         Deletes this item in SDB.
-        
+
         .. note:: This local Python object remains in its current state
             after deletion, this only deletes the remote item in SDB.
         """
         self.domain.delete_item(self)
-
-        
-        
-
