@@ -25,79 +25,78 @@ from tests.unit import unittest
 
 from mock import call, Mock, patch, sentinel
 
+import codecs
 from boto.glacier.layer1 import Layer1
 from boto.glacier.layer2 import Layer2
 import boto.glacier.vault
 from boto.glacier.vault import Vault
 from boto.glacier.vault import Job
 
-from StringIO import StringIO
-
 from datetime import datetime, tzinfo, timedelta
 
 # Some fixture data from the Glacier docs
 FIXTURE_VAULT = {
-  "CreationDate" : "2012-02-20T17:01:45.198Z",
-  "LastInventoryDate" : "2012-03-20T17:03:43.221Z",
-  "NumberOfArchives" : 192,
-  "SizeInBytes" : 78088912,
-  "VaultARN" : "arn:aws:glacier:us-east-1:012345678901:vaults/examplevault",
-  "VaultName" : "examplevault"
+    "CreationDate": "2012-02-20T17:01:45.198Z",
+    "LastInventoryDate": "2012-03-20T17:03:43.221Z",
+    "NumberOfArchives": 192,
+    "SizeInBytes": 78088912,
+    "VaultARN": "arn:aws:glacier:us-east-1:012345678901:vaults/examplevault",
+    "VaultName": "examplevault"
 }
 
 FIXTURE_VAULTS = {
-        'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
-        'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault0',
-                       'VaultName': 'vault0', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:38:39.049Z'},
-                      {'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault3',
-                       'VaultName': 'vault3', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:31:18.659Z'}]}
+    'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
+    'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault0',
+                   'VaultName': 'vault0', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:38:39.049Z'},
+                  {'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault3',
+                   'VaultName': 'vault3', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:31:18.659Z'}]}
 
 FIXTURE_PAGINATED_VAULTS = {
-        'Marker': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault2',
-        'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
-        'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault0',
-                       'VaultName': 'vault0', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:38:39.049Z'},
-                      {'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault1',
-                       'VaultName': 'vault1', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:31:18.659Z'}]}
+    'Marker': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault2',
+    'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
+    'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault0',
+                   'VaultName': 'vault0', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:38:39.049Z'},
+                  {'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault1',
+                   'VaultName': 'vault1', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:31:18.659Z'}]}
 FIXTURE_PAGINATED_VAULTS_CONT = {
-        'Marker': None,
-        'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
-        'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault2',
-                       'VaultName': 'vault2', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:38:39.049Z'},
-                      {'SizeInBytes': 0, 'LastInventoryDate': None,
-                       'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault3',
-                       'VaultName': 'vault3', 'NumberOfArchives': 0,
-                       'CreationDate': '2013-05-17T02:31:18.659Z'}]}
+    'Marker': None,
+    'RequestId': 'vuXO7SHTw-luynJ0Zu31AYjR3TcCn7X25r7ykpuulxY2lv8',
+    'VaultList': [{'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault2',
+                   'VaultName': 'vault2', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:38:39.049Z'},
+                  {'SizeInBytes': 0, 'LastInventoryDate': None,
+                   'VaultARN': 'arn:aws:glacier:us-east-1:686406519478:vaults/vault3',
+                   'VaultName': 'vault3', 'NumberOfArchives': 0,
+                   'CreationDate': '2013-05-17T02:31:18.659Z'}]}
 
 FIXTURE_ARCHIVE_JOB = {
-  "Action": "ArchiveRetrieval",
-  "ArchiveId": ("NkbByEejwEggmBz2fTHgJrg0XBoDfjP4q6iu87-TjhqG6eGoOY9Z8i1_AUyUs"
-                "uhPAdTqLHy8pTl5nfCFJmDl2yEZONi5L26Omw12vcs01MNGntHEQL8MBfGlqr"
-                "EXAMPLEArchiveId"),
-  "ArchiveSizeInBytes": 16777216,
-  "Completed": False,
-  "CreationDate": "2012-05-15T17:21:39.339Z",
-  "CompletionDate": "2012-05-15T17:21:43.561Z",
-  "InventorySizeInBytes": None,
-  "JobDescription": "My ArchiveRetrieval Job",
-  "JobId": ("HkF9p6o7yjhFx-K3CGl6fuSm6VzW9T7esGQfco8nUXVYwS0jlb5gq1JZ55yHgt5v"
-            "P54ZShjoQzQVVh7vEXAMPLEjobID"),
-  "SHA256TreeHash": ("beb0fe31a1c7ca8c6c04d574ea906e3f97b31fdca7571defb5b44dc"
-                     "a89b5af60"),
-  "SNSTopic": "arn:aws:sns:us-east-1:012345678901:mytopic",
-  "StatusCode": "InProgress",
-  "StatusMessage": "Operation in progress.",
-  "VaultARN": "arn:aws:glacier:us-east-1:012345678901:vaults/examplevault"
+    "Action": "ArchiveRetrieval",
+    "ArchiveId": ("NkbByEejwEggmBz2fTHgJrg0XBoDfjP4q6iu87-TjhqG6eGoOY9Z8i1_AUyUs"
+                  "uhPAdTqLHy8pTl5nfCFJmDl2yEZONi5L26Omw12vcs01MNGntHEQL8MBfGlqr"
+                  "EXAMPLEArchiveId"),
+    "ArchiveSizeInBytes": 16777216,
+    "Completed": False,
+    "CreationDate": "2012-05-15T17:21:39.339Z",
+    "CompletionDate": "2012-05-15T17:21:43.561Z",
+    "InventorySizeInBytes": None,
+    "JobDescription": "My ArchiveRetrieval Job",
+    "JobId": ("HkF9p6o7yjhFx-K3CGl6fuSm6VzW9T7esGQfco8nUXVYwS0jlb5gq1JZ55yHgt5v"
+              "P54ZShjoQzQVVh7vEXAMPLEjobID"),
+    "SHA256TreeHash": ("beb0fe31a1c7ca8c6c04d574ea906e3f97b31fdca7571defb5b44dc"
+                       "a89b5af60"),
+    "SNSTopic": "arn:aws:sns:us-east-1:012345678901:mytopic",
+    "StatusCode": "InProgress",
+    "StatusMessage": "Operation in progress.",
+    "VaultARN": "arn:aws:glacier:us-east-1:012345678901:vaults/examplevault"
 }
 
 EXAMPLE_PART_LIST_RESULT_PAGE_1 = {
@@ -106,11 +105,10 @@ EXAMPLE_PART_LIST_RESULT_PAGE_1 = {
     "Marker": "MfgsKHVjbQ6EldVl72bn3_n5h2TaGZQUO-Qb3B9j3TITf7WajQ",
     "MultipartUploadId": "OW2fM5iVylEpFEMM9_HpKowRapC3vn5sSL39_396UW9zLFUWVrnRHaPjUJddQ5OxSHVXjYtrN47NBZ-khxOjyEXAMPLE",
     "PartSizeInBytes": 4194304,
-    "Parts":
-    [ {
-      "RangeInBytes": "4194304-8388607",
-      "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
-      }],
+    "Parts": [{
+        "RangeInBytes": "4194304-8388607",
+        "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
+    }],
     "VaultARN": "arn:aws:glacier:us-east-1:012345678901:vaults/demo1-vault"
 }
 
@@ -122,11 +120,10 @@ EXAMPLE_PART_LIST_RESULT_PAGE_2 = {
     "Marker": None,
     "MultipartUploadId": None,
     "PartSizeInBytes": None,
-    "Parts":
-    [ {
-      "RangeInBytes": "0-4194303",
-      "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
-      }],
+    "Parts": [{
+        "RangeInBytes": "0-4194303",
+        "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
+    }],
     "VaultARN": None
 }
 
@@ -136,14 +133,13 @@ EXAMPLE_PART_LIST_COMPLETE = {
     "Marker": None,
     "MultipartUploadId": "OW2fM5iVylEpFEMM9_HpKowRapC3vn5sSL39_396UW9zLFUWVrnRHaPjUJddQ5OxSHVXjYtrN47NBZ-khxOjyEXAMPLE",
     "PartSizeInBytes": 4194304,
-    "Parts":
-    [ {
-      "RangeInBytes": "4194304-8388607",
-      "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
+    "Parts": [{
+        "RangeInBytes": "4194304-8388607",
+        "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
     }, {
-      "RangeInBytes": "0-4194303",
-      "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
-      }],
+        "RangeInBytes": "0-4194303",
+        "SHA256TreeHash": "01d34dabf7be316472c93b1ef80721f5d4"
+    }],
     "VaultARN": "arn:aws:glacier:us-east-1:012345678901:vaults/demo1-vault"
 }
 
@@ -182,7 +178,7 @@ class TestGlacierLayer2Connection(GlacierLayer2Base):
         def return_paginated_vaults_resp(marker=None, limit=None):
             return resps.pop(0)
 
-        self.mock_layer1.list_vaults = Mock(side_effect = return_paginated_vaults_resp)
+        self.mock_layer1.list_vaults = Mock(side_effect=return_paginated_vaults_resp)
         vaults = self.layer2.list_vaults()
         self.assertEqual(vaults[0].name, "vault0")
         self.assertEqual(vaults[3].name, "vault3")
@@ -224,8 +220,8 @@ class TestVault(GlacierLayer2Base):
                 return timedelta(0)
 
         self.mock_layer1.initiate_job.return_value = {'JobId': 'job-id'}
-        self.vault.retrieve_inventory(start_date=datetime(2014, 01, 01, tzinfo=UTC()),
-                                      end_date=datetime(2014, 01, 02, tzinfo=UTC()),
+        self.vault.retrieve_inventory(start_date=datetime(2014, 0o1, 0o1, tzinfo=UTC()),
+                                      end_date=datetime(2014, 0o1, 0o2, tzinfo=UTC()),
                                       limit=100)
         self.mock_layer1.initiate_job.assert_called_with(
             'examplevault', {
@@ -286,18 +282,18 @@ class TestVault(GlacierLayer2Base):
             'Parts': [{
                 'RangeInBytes': '0-3',
                 'SHA256TreeHash': '12',
-                }, {
+            }, {
                 'RangeInBytes': '4-6',
                 'SHA256TreeHash': '34',
-                },
-        ]}
+            }],
+        }
 
         self.vault.list_all_parts = mock_list_parts
         self.vault.resume_archive_from_file(
             sentinel.upload_id, file_obj=sentinel.file_obj)
         mock_resume_file_upload.assert_called_once_with(
             self.vault, sentinel.upload_id, part_size, sentinel.file_obj,
-            {0: '12'.decode('hex'), 1: '34'.decode('hex')})
+            {0: codecs.decode('12', 'hex_codec'), 1: codecs.decode('34', 'hex_codec')})
 
 
 class TestJob(GlacierLayer2Base):
@@ -308,11 +304,12 @@ class TestJob(GlacierLayer2Base):
 
     def test_get_job_output(self):
         self.mock_layer1.get_job_output.return_value = "TEST_OUTPUT"
-        self.job.get_output((0,100))
+        self.job.get_output((0, 100))
         self.mock_layer1.get_job_output.assert_called_with(
             "examplevault",
             "HkF9p6o7yjhFx-K3CGl6fuSm6VzW9T7esGQfco8nUXVYwS0jlb5gq1JZ55yHgt5vP"
-            "54ZShjoQzQVVh7vEXAMPLEjobID", (0,100))
+            "54ZShjoQzQVVh7vEXAMPLEjobID", (0, 100))
+
 
 class TestRangeStringParsing(unittest.TestCase):
     def test_simple_range(self):
